@@ -49,21 +49,24 @@ class Customer(BaseNModel, DictModel, FullTextSearchable):
     
     memberships_list            = ndb.StringProperty(repeated=True, write_empty_list=True)
     
-    last_transact_date          = ndb.DateProperty(required=False)
+    last_transact_datetime      = ndb.DateTimeProperty(required=False)
+    
+    last_redeemed_datetime      = ndb.DateTimeProperty(required=False)
     
     tier_membership             = ndb.StringProperty(required=False)
     
     reward_summary              = ndb.JsonProperty()
+    entitled_voucher_summary    = ndb.JsonProperty()
     
     fulltextsearch_field_name   = 'name'
     
     dict_properties     = ['name', 'mobile_phone', 'email', 'gender', 'birth_date', 'reference_code', 'merchant_reference_code',  
-                           'tags_list', 'memberships_list', 'tier_membership', 'registered_merchant_acct',
+                           'tags_list', 'memberships_list', 'tier_membership', 'registered_merchant_acct', 'reward_summary', 'entitled_voucher_summary',
                            'registered_outlet_key', 'registered_merchant_acct_key', 'registered_datetime', 'modified_datetime']
     
     @property
     def registered_user_acct_key(self):
-        return self.key.parent().urlsafe()
+        return self.key.parent().urlsafe().decode('utf-8')
     
     @property
     def registered_user_acct(self):
