@@ -15,7 +15,7 @@ from trexlib.utils.string_util import random_number, is_empty, is_not_empty,\
 import logging
 from datetime import datetime, timedelta
 from trexlib.utils.common.date_util import parse_datetime
-from trexmodel import conf
+from trexmodel import conf, program_conf
 from google.auth._default import default
 from trexmodel.models.datastore.system_models import Tagging
 
@@ -96,6 +96,18 @@ class MerchantAcct(MerchantMin):
         
         return (search_results, total_count, next_cursor)
     
+    @property
+    def manual_giveaway_reward_program_list(self):
+        published_program_configuration = self.published_program_configuration
+        program_list = []
+        
+        for program in published_program_configuration.get('programs'):
+            if program.get('reward_base') == program_conf.REWARD_BASE_ON_GIVEAWAY:
+                if program.get('giveaway_method') == program_conf.PROGRAM_REWARD_GIVEAWAY_METHOD_MANUAL:
+                    program_list.append(program)
+        
+        
+        return program_list
     
     def flush_dirty_program_configuration(self):
         if self.published_program_configuration and len(self.published_program_configuration)>0:
