@@ -213,6 +213,10 @@ class BaseNModel(DictModel, NDBModel):
 
     def _post_put_hook(self, future):
         self.saved = True
+        
+    @property
+    def parent_key(self):
+        return self.key.parent().urlsafe().decode('utf-8')
 
     @property
     def key_in_str(self):
@@ -262,7 +266,7 @@ class BaseNModel(DictModel, NDBModel):
     
     @classmethod
     def list_all(cls, offset=0,  start_cursor=None, return_with_cursor=False, keys_only=False, 
-                 limit=model_conf.PAGINATION_SIZE):
+                 limit=model_conf.MAX_FETCH_RECORD):
         
         query = cls.query()
         
@@ -274,7 +278,7 @@ class BaseNModel(DictModel, NDBModel):
     
     @classmethod
     def list_all_with_condition_query(cls, query, offset=0,  start_cursor=None, return_with_cursor=False, keys_only=False, 
-                 limit=model_conf.PAGINATION_SIZE):
+                 limit=model_conf.MAX_FETCH_RECORD):
         
         
         
