@@ -23,7 +23,7 @@ class ProgramBase(BaseNModel, DictModel):
     reward_base             = ndb.StringProperty(required=True, choices=set(program_conf.REWARD_BASE_SET))
     reward_format           = ndb.StringProperty(required=False, choices=set(program_conf.REWARD_FORMAT_SET))
     completed_status        = ndb.StringProperty(required=True, choices=set(program_conf.PROGRAM_STATUS))
-    giveaway_method         = ndb.StringProperty(required=False, default=program_conf.PROGRAM_REWARD_GIVEAWAY_METHOD_AUTO)
+    giveaway_method         = ndb.StringProperty(required=False, default=program_conf.PROGRAM_REWARD_GIVEAWAY_METHOD_SYSTEM)
     start_date              = ndb.DateProperty(required=True)
     end_date                = ndb.DateProperty(required=True)
     desc                    = ndb.StringProperty(required=False)
@@ -146,6 +146,7 @@ class ProgramBase(BaseNModel, DictModel):
                                 'desc'              : self.desc,
                                 'reward_base'       : self.reward_base,
                                 'reward_format'     : self.reward_format,
+                                'giveaway_method'   : self.giveaway_method,
                                 'start_date'        : self.start_date.strftime('%d-%m-%Y'),
                                 'end_date'          : self.end_date.strftime('%d-%m-%Y'),    
                                 'program_settings'  : self.program_settings,
@@ -154,20 +155,6 @@ class ProgramBase(BaseNModel, DictModel):
         
         return program_configuration
     
-    def to_program_setttings(self):
-        program_setttings = {
-                                'program_key'       : self.key_in_str,
-                                'desc'              : self.desc,
-                                'reward_base'       : self.reward_base,
-                                'reward_format'     : self.reward_format,
-                                'start_date'        : self.start_date.strftime('%d-%m-%Y'),
-                                'end_date'          : self.end_date.strftime('%d-%m-%Y'),    
-                                'program_settings'  : self.program_settings,
-                                'is_published'      : self.is_published,   
-                                }
-        
-        return program_setttings
-    
     @classmethod
     def update_program_base_data(cls, program, reward_base=None, reward_format=None, giveaway_method=None, 
                                  desc=None,start_date=None, end_date=None, modified_by=None):
