@@ -5,7 +5,7 @@ Created on 10 Apr 2020
 '''
 from google.cloud import ndb
 from trexmodel.models.datastore.ndb_models import BaseNModel, DictModel
-from trexlib.utils.common.cache_util import cache
+#from trexlib.utils.common.cache_util import cache
 from trexlib.utils.string_util import random_number
 from flask_login import UserMixin
 import logging  
@@ -41,7 +41,7 @@ class UserMin(BaseNModel, DictModel, UserMixin):
     dict_properties             = ['user_id', 'name', 'email', 'gravatar_url', 'active', 'locked']
     
     @classmethod
-    @cache.memoize(timeout=60)
+    #@cache.memoize(timeout=60)
     def get_by_user_id(cls, user_id):
         logger.debug('UserMin.get_by_user_id: read from database')
         return cls.query(cls.user_id==user_id).get()
